import React__default, { useState, useCallback } from 'react';
import SwipeableViews from 'react-swipeable-views';
import { ArrowLeftIcon, ArrowRightIcon } from '@rescui/icons';
import { useTheme } from '@rescui/ui-contexts';
import { useTextStyles } from '@rescui/typography';
import cn from 'classnames';
import SvgQuote from './quote.svg.js';
import styles from './quotes-slider.module.pcss.js';

const QuotesSlider = props => {
  const {
    quotes,
    large,
    ...rest
  } = props;
  const [index, setIndex] = useState(0);
  const totalSlides = quotes.length;
  const handleNextSlide = useCallback(() => {
    if (index + 1 < totalSlides) {
      setIndex(index + 1);
    }
  }, [index]);
  const handlePrevSlide = useCallback(() => {
    if (index > 0) {
      setIndex(index - 1);
    }
  }, [index]);
  const handleChangeIndex = useCallback(i => {
    setIndex(i);
  }, [index]);
  const slideTitle = quotes[index].title;
  const prevButtonClass = cn([styles.control, styles.controlPrev], {
    [styles.controlActive]: index > 0
  });
  const nextButtonClass = cn(styles.control, {
    [styles.controlActive]: index + 1 < totalSlides
  });
  const textCn = useTextStyles();
  const theme = useTheme();
  const quoteTextClass = large ? textCn('rs-subtitle-2') : textCn('rs-text-1');
  return React__default.createElement("div", {
    className: cn(styles.quotesSlider, {
      [styles.quotesSliderDarkTheme]: theme === 'dark'
    })
  }, React__default.createElement("div", {
    className: styles.content
  }, React__default.createElement("div", {
    className: cn(styles.iconContainer, {
      [styles.iconContainerDarkTheme]: theme === 'dark'
    })
  }, React__default.createElement(SvgQuote, null)), React__default.createElement("div", null, quotes.length > 1 ? React__default.createElement(SwipeableViews, {
    index: index,
    onChangeIndex: handleChangeIndex,
    ...rest
  }, quotes.map((quote, i) => React__default.createElement("p", {
    className: cn(quoteTextClass, styles.quoteText),
    key: i
  }, quote.text))) : React__default.createElement("p", {
    className: cn(quoteTextClass, styles.quoteText)
  }, quotes[0].text), React__default.createElement("div", {
    className: styles.nav
  }, React__default.createElement("div", {
    className: styles.title
  }, React__default.createElement("p", {
    className: textCn('rs-text-2')
  }, slideTitle)), quotes.length > 1 && React__default.createElement("div", {
    className: styles.controls
  }, React__default.createElement("div", {
    className: prevButtonClass,
    onClick: handlePrevSlide
  }, React__default.createElement(ArrowLeftIcon, {
    theme: theme
  })), React__default.createElement("div", {
    className: styles.slidesCount
  }, React__default.createElement("p", {
    className: textCn('rs-text-2')
  }, index + 1, "/", totalSlides)), React__default.createElement("div", {
    className: nextButtonClass,
    onClick: handleNextSlide
  }, React__default.createElement(ArrowRightIcon, {
    theme: theme
  })))))));
};

export { QuotesSlider };
